@@ -121,6 +121,9 @@
 #define	D_XFACE		25	/* XFace display string			*/
 #define	D_NO_XFACE	26	/* No XFace file display string		*/
 #define D_FORWARD_DENY	27	/* No Forwarding string			*/
+#define	D_IDENT_CONREF	28	/* Connection refused for RFC1413 report*/
+#define	D_IDENT_ILLEGAL	29	/* Illegal data in RFC1413 report	*/
+#define	D_IDENT_TIMEOUT	30	/* RFC1413 report timed out		*/
 
 /* General program errors */
 #define	E_STANDALONE	1	/* Cannot run in standalone mode	*/
