@@ -119,6 +119,9 @@ TYPEVAL internal_strings[] = {
 	{ "FAKE_USER", D_FAKE_USER, 0 },
 	{ "WHOIS_USER", D_WHOIS_USER, 0 },
 	{ "FORWARD_DENY", D_FORWARD_DENY, 0 },
+	{ "IDENT_CONREF", D_IDENT_CONREF, 0 },
+	{ "IDENT_ILLEGAL", D_IDENT_ILLEGAL, 0 },
+	{ "IDENT_TIMEOUT", D_IDENT_TIMEOUT, 0 },
 	{ NULL, 0, 0 }
 };
 
@@ -209,9 +212,11 @@ void do_files(char *str)
 		    strmcpy(&prog_config.no_finger_file, (char *) filename);
 		else if (!(strncasecmp(element, "LOGFILE", 7))) {
 		    strmcpy(&prog_config.log_file, (char *) filename);
+
 		    PRIV_ROOT_START
 		    logfile = fopen(filename, "a+");
 		    PRIV_ROOT_END
+
 		    if (logfile)
 			can_log = TRUE;
 		    else {
@@ -230,7 +235,9 @@ void do_files(char *str)
 		    strmcpy(&prog_config.rejected_file, (char *) filename);
 		else if (!(strncasecmp(element, "USERLOG", 7)))
 		    strmcpy(&prog_config.userlog_file, (char *) filename);
-		else {
+		else if (element[0] == '#') {
+		    /* Ignore commented out lines */
+		} else {
 		    errors++;
 		    printf("Option %s unknown in display_files.\n", element);
 		}
