@@ -31,7 +31,7 @@ void show_search(char *uname)
 {
     char search[7], searchname[80];
     int num_searches = 0, fnd = 0;
-    SEARCHLIST searches[100];
+    SEARCHLIST searches[500];
     FILE *file;
 
     show_top();
@@ -44,6 +44,15 @@ void show_search(char *uname)
 	exit(PROGRAM_OKAY);
     }
 
+    if ((searchname[0] = '*') && (strlen((char*) searchname) == 1)) {
+	printf("\n                    You must supply a name to search for!\n");
+	SEND_RAW_RETURN;
+	show_bottom();
+	log(LOG_USER, "Security breach: finger * from %s", ident_user);
+	syslog(LOG_WARNING, "Security breach: finger * from %s", ident_user);
+	exit(PROGRAM_OKAY);
+    }
+
     log(LOG_USER, "Search: ", searchname);
 
     file = fopen("/etc/passwd", "r");
@@ -74,9 +83,7 @@ void show_search(char *uname)
 		if (isupper(*cp))
 		    *cp = tolower (*cp);
 
-	    /* Check for trusted/untrusted hosts here */
-	    /* For the sake of gcos password fields */
-	    if ((cp = index(Rn,',')))
+	    if ((cp = index(rn,',')))
 		*cp = '\0';
 
 	    if (strstr((char *) rn, (char *) searchname))
@@ -87,8 +94,6 @@ void show_search(char *uname)
 		fnd = TRUE;
 
 	    if (fnd) {
-		char crap2[80];
-
 		bzero(searches[num_searches].realname, 80);
 		bzero(searches[num_searches].username, 80);
 
