@@ -20,6 +20,8 @@
 #endif
 #include <lastlog.h>
 
+#include "privs.h"
+
 int columns;
 int times_on;
 
@@ -544,7 +546,7 @@ void show_login_stats(char *user)
 		sprintf(devfile, "/dev/%s", (char *) ut->ut_line);
 		stat(devfile, &buf);
 
-		if (buf.st_mode & S_IWGRP)
+		if ((buf.st_mode & S_IWGRP) && (buf.st_mode & S_IWOTH))
 		    tty_list[times_on].writable = TRUE;
 		else
 		    tty_list[times_on].writable = FALSE;
@@ -649,12 +651,17 @@ void show_fingerinfo(char *user)
     FILE *file;
     char username[80], room[80], work_phone[80], home_phone[80],
 	 other[80], fn[80];
+    int nuid, ngid;
 
     columns = 0;
     pwent = getpwnam(user);
 
     uid = pwent->pw_uid;
 
+    /* For changing to the correct UID/GID */
+    nuid = pwent->pw_uid;
+    ngid = pwent->pw_gid;
+
     username[0] = 0;
     room[0] = 0;
     work_phone[0] = 0;
@@ -718,12 +725,18 @@ void show_fingerinfo(char *user)
 	if (prog_config.config_bits2 & SHOW_STRICTFMT)
 	    SEND_RAW_RETURN;
 
-	show_pfile(SHOW_PROJECT, D_PLAN, D_NO_PLAN, pwent->pw_dir,
-		prog_config.plan_file,
+	/* I made a typo here ... thanks to stig@hackvan.com, it was
+	   corrected. */
+
+	/* User priviledges patch thanks to Dan Hollis */
+	USER_PRIVS(nuid,ngid)
+
+	show_pfile(SHOW_PROJECT, D_PROJECT, D_NO_PROJECT, pwent->pw_dir, 
+		prog_config.project_file, 
 	(prog_config.config_bits2 & SHOW_STRICTFMT) ? FALSE : TRUE);
 
-	show_pfile(SHOW_PLAN, D_PROJECT, D_NO_PROJECT, pwent->pw_dir, 
-		prog_config.project_file, 
+	show_pfile(SHOW_PLAN, D_PLAN, D_NO_PLAN, pwent->pw_dir,
+		prog_config.plan_file,
 	(prog_config.config_bits2 & SHOW_STRICTFMT) ? FALSE : TRUE);
 
 	/* Thanks to Andy Smith */
@@ -733,6 +746,8 @@ void show_fingerinfo(char *user)
 
 	show_pfile2(SHOW_XFACE, D_XFACE, D_NO_XFACE, pwent->pw_dir,
 		prog_config.xface_file, FALSE);
+
+	RELINQUISH_PRIVS
     }
 }
 
