@@ -19,6 +19,7 @@
 #ifdef	BSD
 #include "getutent.h"
 #endif
+#include "privs.h"
 
 #include <regex.h>
 
@@ -111,18 +112,6 @@ void start_cfingerd(void)
 void check_stats()
 {
     if (!emulated) {
-/*
-	if (geteuid()) {
-	    syslog(LOG_ERR, "cfingerd is not running as root");
-	    CF_ERROR(E_NONROOT);
-	}
-
-	if (getuid()) {
-	    syslog(LOG_ERR, "cfingerd cannot suid root");
-	    CF_ERROR(E_SUIDROOT);
-	}
-
-*/
 	if (isatty(0)) {
 	    syslog(LOG_ERR, "cfingerd run from command line/daemon");
 	    CF_ERROR(E_INETD);
@@ -314,7 +303,9 @@ void display_file(char *filename)
     char line[128];
     int bsize = sizeof(line);
 
+    PRIV_ROOT_START
     file = fopen(filename, "r");
+    PRIV_ROOT_END
 
     if (file) {
 	while(fgets(line, bsize, file)) {
@@ -447,41 +438,6 @@ char *get_localhost(void)
     return(ret);
 }
 
-/*
- * BECOME_NOBODY
- *
- * Change to the nobody user ID / group ID
-void become_nobody(void)
-{
-    if ((setgid(NOBODY_GID)) == -1)
-	syslog(LOG_WARNING, "setgid(NOBODY): %s", strerror(errno));
-
-    if ((setuid(NOBODY_UID)) == -1)
-	syslog(LOG_WARNING, "setuid(NOBODY): %s", strerror(errno));
-}
-
- * BECOME_USER
- *
- * This changes user IDs to the specified username.
-void become_user(char *username)
-{
-    struct passwd *pw;
-
-    pw = getpwnam(username);
-
-    if (pw != NULL) {
-	if ((setgid(pw->pw_gid)) == -1)
-	    syslog(LOG_WARNING, "setgid(%s): %s", username, strerror(errno));
-
-	if ((setuid(pw->pw_uid)) == -1)
-	    syslog(LOG_WARNING, "setuid(%s): %s", username, strerror(errno));
-    } else {
-	syslog(LOG_WARNING, "become_user failed.  Becoming nobody.");
-	become_nobody();
-    }
-}
-*/
-
 /*
  * CHECK_UNKNOWN
  *
