@@ -13,7 +13,7 @@
  * GNU General Public License for more details.
  */
 
-#define	VERSION			"1.2.2"
+#define	VERSION			"1.3.0"
 
-/* #define	LAST_STABLE_RELEASE	"1.1.1"
-#define		IN_TESTING		1 */
+#define	LAST_STABLE_RELEASE	"1.2.3"
+#define	IN_TESTING		1
